@@ -116,6 +116,16 @@ create_profile_callback (struct SRowSet *rowset, gpointer data)
 	GtkTreeSelection *selection;
 	GtkWidget *dialog, *view;
 	GtkVBox *vbox;
+	const gchar *username = (const gchar *)data;
+
+	/* If we can find the exact username, then find & return its index. */
+	for (i = 0; i < rowset->cRows; i++) {
+		lpProp_account = get_SPropValue_SRow(&(rowset->aRow[i]), PR_ACCOUNT);
+
+		if (lpProp_account && lpProp_account->value.lpszA &&
+		    !g_strcmp0 (username, lpProp_account->value.lpszA))
+			return i;
+	}
 
 	/* NOTE: A good way would be display the list of username entries */
 	/* using GtkEntryCompletion in the username gtkentry. But plugins */
@@ -190,17 +200,6 @@ validate_credentials (GtkWidget *widget, EConfig *config)
 	url = camel_url_new (e_account_get_string (target_account->account, E_ACCOUNT_SOURCE_URL), NULL);
 	domain_name = camel_url_get_param (url, "domain");
 
-	/* Silently remove domain part from a user name when user enters it as such.
-	   This change will be visible in the UI on new edit open. */
-	if (url->user && strchr (url->user, '\\')) {
-		gchar *tmp, *at;
-
-		at = strrchr (url->user, '\\') + 1;
-		tmp = g_strdup (at);
-		camel_url_set_user (url, tmp);
-		g_free (tmp);
-	}
-
 	if (!url->user || !*url->user || !url->host || !*url->host || !domain_name || !*domain_name) {
 		e_notice (NULL, GTK_MESSAGE_ERROR, "%s", _("Server, username and domain name cannot be empty. Please fill them with correct values."));
 		return;
@@ -208,11 +207,10 @@ validate_credentials (GtkWidget *widget, EConfig *config)
 
 	key = camel_url_to_string (url, CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
 	password = e_passwords_get_password (EXCHANGE_MAPI_PASSWORD_COMPONENT, key);
-	if (!password || !*password) {
+	if (!password) {
 		gboolean remember = FALSE;
 		gchar *title;
 
-		g_free (password);
 		title = g_strdup_printf (_("Enter Password for %s@%s"), url->user, url->host);
 		password = e_passwords_ask_password (title, EXCHANGE_MAPI_PASSWORD_COMPONENT, key, title,
 						     E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET,
@@ -226,12 +224,12 @@ validate_credentials (GtkWidget *widget, EConfig *config)
 		gboolean status = exchange_mapi_create_profile (url->user, password, domain_name,
 								url->host, &error_msg, 
 								(mapi_profile_callback_t) create_profile_callback,
-								NULL);
+								url->user);
 		if (status) {
 			/* Things are successful */
 			gchar *profname = NULL, *uri = NULL; 
 
-			profname = exchange_mapi_util_profile_name (url->user, domain_name);
+			profname = g_strdup_printf("%s@%s", url->user, domain_name);
 			camel_url_set_param(url, "profile", profname);
 			g_free (profname);
 
@@ -254,9 +252,6 @@ validate_credentials (GtkWidget *widget, EConfig *config)
 		}
 
 		g_free (error_msg);
-	} else {
-		e_passwords_forget_password (EXCHANGE_MAPI_PASSWORD_COMPONENT, key);
-		e_notice (NULL, GTK_MESSAGE_ERROR, "%s", _("Authentication failed."));
 	}
 
 	g_free (password);
